@@ -14,7 +14,18 @@ from pyefun.progiterUtil import *
 from pyefun.stringUtil import *
 from pyefun.timeUtil import *
 
+from pyefun.regexpUtil import *
+
 from pyefun.threadingUtil import *
 from pyefun.networkUtil import *
+from pyefun.configUtil import *
+from pyefun.configEnvUtil import *
+from pyefun.clockUtil import *
 
-__version__ = '1.0.11'
\ No newline at end of file
+from pyefun.encoding.compress.egzip import *
+from pyefun.encoding.compress.ezlib import *
+from pyefun.encoding.ebinary.binary import *
+from pyefun.encoding.ebase64.ebase64 import *
+from pyefun.encoding.url.url import *
+
+__version__ = '1.0.17'
\ No newline at end of file
