@@ -1,18 +1,43 @@
+import random
+
 import ubelt as ub
 from collections import OrderedDict
 import operator
 from .dirkBase import *
+from .stringUtil import *
 import hashlib
+import uuid
 
 
+def 取uuid():
+    return str(uuid.uuid4())
+def 取短id():
+    array = ["a", "b", "c", "d", "e", "f",
+             "g", "h", "i", "j", "k", "l", "m", "n", "o", "p", "q", "r", "s",
+             "t", "u", "v", "w", "x", "y", "z", "0", "1", "2", "3", "4", "5",
+             "6", "7", "8", "9", "A", "B", "C", "D", "E", "F", "G", "H", "I",
+             "J", "K", "L", "M", "N", "O", "P", "Q", "R", "S", "T", "U", "V",
+             "W", "X", "Y", "Z"]
+    id = str(uuid.uuid4()).replace("-", '')
+    buffer = []
+
+    for i in range(0, 8):
+        start = i * 4
+        end = i * 4 + 4
+        val = int(id[start:end], 16)
+        buffer.append(array[val % 62])
+    return "".join(buffer)
+
 def 取sha1(data, 哈希算法='sha1'):
     return ub.hash_data(data, hasher=哈希算法)
 
+
 def 取md5(内容, 编码="utf-8"):
     MD5 = hashlib.md5()
     MD5.update(内容.encode(encoding=编码))
     return MD5.hexdigest()
 
+
 def 取哈希(data, 哈希算法='sha1'):
     return ub.hash_data(data, hasher=哈希算法)
 
@@ -177,6 +202,10 @@ def 数组_查找重复项(items, 至少出现=2):
     return data
 
 
+def 数组_随机排序(items):
+    return random.shuffle(items)
+
+
 def 命令行_获取参数(参数名, 默认值=ub.util_const.NoParam, argv=None):
     return ub.argval(参数名, 默认值, argv)
 
@@ -215,13 +244,39 @@ def 路径_替换为用户路径(path, home='~'):
     return ub.shrinkuser(path, home)
 
 
-def 路径_扩展路径(path):
-    return ub.expandpath(path)
+def 路径_展开路径(path):
+    r"""
+
+    :param path:  ~/foo
+    :return: C:\Users\foo
+    """
+
+    return 路径_优化路径(ub.expandpath(path))
 
 
 def 路径_优化路径(path):
+    """
+    把\\ // 乱七八糟的路径转化为规整的
+
+    :param path:
+    :return:
+    """
+    if 寻找文本(path,"\\") > -1:
+        path = 子文本替换(path,"\\","/")
+    if 寻找文本(path, r"\\") > -1:
+        path = 子文本替换(path,r"\\","/")
+    if 寻找文本(path,"//") > -1:
+        path = 子文本替换(path,r"//","/")
     return ub.util_path.normpath(path)
 
+def 路径_合并(*path):
+    """
+    a b c d 合并为 a/b/c/d 并且自动优化路径
+    :param path:
+    :return:
+    """
+    return 路径_优化路径(ub.util_path.join(*path))
+
 
 def 目录_创建(路径, 权限=0o1777, 显示信息=None, 重建=False):
     return ub.ensuredir(路径, 权限, 显示信息, 重建)
@@ -613,6 +668,3 @@ def 结束(*args, **kwargs):
     操作系统需求： Windows、Linux、Unix
     """
     return exit(args, **kwargs)
-
-
-
