@@ -1,6 +1,6 @@
 import unittest
 
-from .typeConv import *
+from .__init__ import *
 
 
 class TestTypeConv(unittest.TestCase):
@@ -19,6 +19,14 @@ class TestTypeConv(unittest.TestCase):
         data = 到数值("123.123")
         print(type(data), data)
 
-
         data = 到时间("2021-05-18")
         print(type(data), data)
+
+    def test_2(self):
+        data = json到文本({"a": 1, "b": 2,"name":"你好"})
+        print(data)
+        data = json解析(data)
+        调试输出(data)
+        print(data['a'])
+        print(data['b'])
+        print(data['name'])
